Unconditionally stop testing a tinytest test file, preventing additional tests in the file from running without triggering a failure. This is the low-level exit function for other skip_() functions in tinyexpect

skip(message = "Skipping")

Arguments

message

A message describing why the test file is being skipped

Value

If called within a tinytest test, triggers an exit condition; otherwise, returns message

Examples

skip()
#> [1] "Skipping"