Conditionally stop testing a tinytest test file if running on the Bioconductor Build System. This is determined by checking if the environment variable “IS_BIOC_BUILD_MACHINE” set and is a non-FALSE value

skip_on_bioc()

exit_on_bioc()

Value

If called within a tinytest test running on the Bioconductor Build System, triggers an exit condition; otherwise, either a string saying “On Bioconductor” or NULL invisibly

Examples

withr::with_envvar(c(IS_BIOC_BUILD_MACHINE = "true"), skip_on_bioc())
#> [1] "On Bioconductor"