Unconditionally stop testing a tinytest test file, preventing
additional tests in the file from running without triggering a failure. This
is the low-level exit function for other skip_() functions in
tinyexpect
skip(message = "Skipping")If called within a tinytest test, triggers an exit
condition; otherwise, returns message
testthat equivalent:
testthat::skip()
Other "stop testing" functions:
skip_if_not_installed(),
skip_on_bioc(),
skip_on_ci(),
skip_on_covr(),
skip_on_cran(),
skip_on_os()
skip()
#> [1] "Skipping"