Conditionally stop testing a tinytest test file if running on
the Bioconductor Build System. This is determined by checking if the
environment variable “IS_BIOC_BUILD_MACHINE” set and is
a non-FALSE value
skip_on_bioc()
exit_on_bioc()If called within a tinytest test running on the
Bioconductor Build System, triggers an exit condition; otherwise, either
a string saying “On Bioconductor” or NULL invisibly
testthat equivalent:
testthat::skip_on_bioc()
Other "stop testing" functions:
skip(),
skip_if_not_installed(),
skip_on_ci(),
skip_on_covr(),
skip_on_cran(),
skip_on_os()
withr::with_envvar(c(IS_BIOC_BUILD_MACHINE = "true"), skip_on_bioc())
#> [1] "On Bioconductor"